@@ -1,5 +1,5 @@
 import json
-from typing import TypeVar, Generic, Union, Optional, Literal
+from typing import TypeVar, Generic, Union, Optional, Literal, List, Dict
 from datetime import datetime, date
 
 
