@@ -13,8 +13,8 @@ class IndividualApplicationDTO(object):
     def __init__(self, id: str, created_at: datetime, full_name: FullName, address: Address, date_of_birth: date,
                  email: str, phone: Phone, status: ApplicationStatus, ssn: Optional[str], message: Optional[str],
                  ip: Optional[str], ein: Optional[str], dba: Optional[str],
-                 sole_proprietorship: Optional[bool], tags: Optional[dict[str, str]],
-                 relationships: Optional[dict[str, Relationship]]):
+                 sole_proprietorship: Optional[bool], tags: Optional[Dict[str, str]],
+                 relationships: Optional[Dict[str, Relationship]]):
         self.id = id
         self.type = "individualApplication"
         self.attributes = {"createdAt": created_at, "fullName": full_name, "address": address,
@@ -41,7 +41,7 @@ class BusinessApplicationDTO(object):
                  status: ApplicationStatus, state_of_incorporation: str, entity_type: EntityType,
                  contact: BusinessContact, officer: Officer, beneficial_owners: [BeneficialOwner], ssn: Optional[str],
                  message: Optional[str], ip: Optional[str], ein: Optional[str], dba: Optional[str],
-                 tags: Optional[dict[str, str]], relationships: Optional[dict[str, Relationship]]):
+                 tags: Optional[Dict[str, str]], relationships: Optional[Dict[str, Relationship]]):
         self.id = id
         self.type = "businessApplication"
         self.attributes = {"createdAt": created_at, "name": name, "address": address, "phone": phone,
@@ -54,12 +54,13 @@ class BusinessApplicationDTO(object):
     @staticmethod
     def from_json_api(_id, _type, attributes, relationships):
         return BusinessApplicationDTO(
-            _id, date_utils.to_datetime(attributes["createdAt"]),attributes.get("name"),
-            Address.from_json_api(attributes["address"]), Phone.from_json_api(attributes["phone"]), attributes["status"],
-            attributes.get("stateOfIncorporation"), attributes.get("entityType"),
+            _id, date_utils.to_datetime(attributes["createdAt"]), attributes.get("name"),
+            Address.from_json_api(attributes["address"]), Phone.from_json_api(attributes["phone"]),
+            attributes["status"], attributes.get("stateOfIncorporation"), attributes.get("entityType"),
             BusinessContact.from_json_api(attributes["contact"]), Officer.from_json_api(attributes["officer"]),
-            BeneficialOwner.from_json_api(attributes["beneficialOwners"]),  attributes.get("ssn"), attributes.get("message"),
-            attributes.get("ip"), attributes.get("ein"), attributes.get("dba"), attributes.get("tags"), relationships
+            BeneficialOwner.from_json_api(attributes["beneficialOwners"]),  attributes.get("ssn"),
+            attributes.get("message"), attributes.get("ip"), attributes.get("ein"), attributes.get("dba"),
+            attributes.get("tags"), relationships
         )
 
 ApplicationDTO = Union[IndividualApplicationDTO, BusinessApplicationDTO]
@@ -78,7 +79,7 @@ class CreateIndividualApplicationRequest(UnitRequest):
         self.sole_proprietorship = sole_proprietorship
         self.ssn = ssn
 
-    def to_json_api(self) -> dict:
+    def to_json_api(self) -> Dict:
         payload = {
             "data": {
                 "type": "individualApplication",
@@ -130,7 +131,7 @@ class CreateBusinessApplicationRequest(UnitRequest):
         self.ip = ip
         self.website = website
 
-    def to_json_api(self) -> dict:
+    def to_json_api(self) -> Dict:
         payload = {
             "data": {
                 "type": "businessApplication",
@@ -175,9 +176,10 @@ class ApplicationDocumentDTO(object):
 
     @staticmethod
     def from_json_api(_id, _type, attributes):
+        address = Address.from_json_api(attributes.get("address")) if attributes.get("address") else None
         return ApplicationDocumentDTO(
             _id, attributes["status"], attributes["documentType"], attributes["description"], attributes["name"],
-            attributes.get("address"), attributes.get("dateOfBirth"), attributes.get("passport"),
+            address, attributes.get("dateOfBirth"), attributes.get("passport"),
             attributes.get("ein"), attributes.get("reasonCode"), attributes.get("reason")
         )
 
