@@ -5,16 +5,16 @@ from unit.utils import date_utils
 from unit.models import *
 
 class BaseEvent(object):
-    def __init__(self, id: str, created_at: datetime, tags: Optional[dict[str, str]],
-                 relationships: Optional[dict[str, Relationship]]):
+    def __init__(self, id: str, created_at: datetime, tags: Optional[Dict[str, str]],
+                 relationships: Optional[Dict[str, Relationship]]):
         self.id = id
         self.attributes = {"createdAt": created_at, "tags": tags}
         self.relationships = relationships
 
 
 class AccountClosedEvent(BaseEvent):
-    def __init__(self, id: str, created_at: datetime, close_reason: str, tags: Optional[dict[str, str]],
-                 relationships: Optional[dict[str, Relationship]]):
+    def __init__(self, id: str, created_at: datetime, close_reason: str, tags: Optional[Dict[str, str]],
+                 relationships: Optional[Dict[str, Relationship]]):
         BaseEvent.__init__(self, id, created_at, tags, relationships)
         self.type = 'account.closed'
         self.attributes["closeReason"] = close_reason
@@ -22,12 +22,12 @@ class AccountClosedEvent(BaseEvent):
     @staticmethod
     def from_json_api(_id, _type, attributes, relationships):
         return AccountClosedEvent(_id, date_utils.to_datetime(attributes["createdAt"]), attributes["closeReason"],
-                             attributes.get("tags"), relationships)
+                                  attributes.get("tags"), relationships)
 
 
 class AccountFrozenEvent(BaseEvent):
-    def __init__(self, id: str, created_at: datetime, freeze_reason: str, tags: Optional[dict[str, str]],
-                 relationships: Optional[dict[str, Relationship]]):
+    def __init__(self, id: str, created_at: datetime, freeze_reason: str, tags: Optional[Dict[str, str]],
+                 relationships: Optional[Dict[str, Relationship]]):
         BaseEvent.__init__(self, id, created_at, tags, relationships)
         self.type = 'account.frozen'
         self.attributes["freezeReason"] = freeze_reason
@@ -35,12 +35,12 @@ class AccountFrozenEvent(BaseEvent):
     @staticmethod
     def from_json_api(_id, _type, attributes, relationships):
         return AccountFrozenEvent(_id, date_utils.to_datetime(attributes["createdAt"]), attributes["freezeReason"],
-                             attributes.get("tags"), relationships)
+                                  attributes.get("tags"), relationships)
 
 
 class ApplicationDeniedEvent(BaseEvent):
-    def __init__(self, id: str, created_at: datetime, tags: Optional[dict[str, str]],
-                 relationships: Optional[dict[str, Relationship]]):
+    def __init__(self, id: str, created_at: datetime, tags: Optional[Dict[str, str]],
+                 relationships: Optional[Dict[str, Relationship]]):
         BaseEvent.__init__(self, id, created_at, tags, relationships)
         self.type = 'application.denied'
 
@@ -51,32 +51,32 @@ class ApplicationDeniedEvent(BaseEvent):
 
 
 class ApplicationPendingReviewEvent(BaseEvent):
-    def __init__(self, id: str, created_at: datetime, tags: Optional[dict[str, str]],
-                 relationships: Optional[dict[str, Relationship]]):
+    def __init__(self, id: str, created_at: datetime, tags: Optional[Dict[str, str]],
+                 relationships: Optional[Dict[str, Relationship]]):
         BaseEvent.__init__(self, id, created_at, tags, relationships)
         self.type = 'application.pendingReview'
 
     @staticmethod
     def from_json_api(_id, _type, attributes, relationships):
-        return ApplicationPendingReviewEvent(_id, date_utils.to_datetime(attributes["createdAt"]), attributes.get("tags"),
-                                  relationships)
+        return ApplicationPendingReviewEvent(_id, date_utils.to_datetime(attributes["createdAt"]),
+                                             attributes.get("tags"), relationships)
 
 
 class ApplicationAwaitingDocumentsEvent(BaseEvent):
-    def __init__(self, id: str, created_at: datetime, tags: Optional[dict[str, str]],
-                 relationships: Optional[dict[str, Relationship]]):
+    def __init__(self, id: str, created_at: datetime, tags: Optional[Dict[str, str]],
+                 relationships: Optional[Dict[str, Relationship]]):
         BaseEvent.__init__(self, id, created_at, tags, relationships)
         self.type = 'application.awaitingDocuments'
 
     @staticmethod
     def from_json_api(_id, _type, attributes, relationships):
-        return ApplicationAwaitingDocumentsEvent(_id, date_utils.to_datetime(attributes["createdAt"]), attributes.get("tags"),
-                                  relationships)
+        return ApplicationAwaitingDocumentsEvent(_id, date_utils.to_datetime(attributes["createdAt"]),
+                                                 attributes.get("tags"), relationships)
 
 
 class AuthorizationCreatedEvent(BaseEvent):
     def __init__(self, id: str, created_at: datetime, card_last_4_digits: str, recurring: str,
-                 tags: Optional[dict[str, str]], relationships: Optional[dict[str, Relationship]]):
+                 tags: Optional[Dict[str, str]], relationships: Optional[Dict[str, Relationship]]):
         BaseEvent.__init__(self, id, created_at, tags, relationships)
         self.type = 'authorization.created'
         self.attributes["cardLast4Digits"] = card_last_4_digits
@@ -90,8 +90,8 @@ class AuthorizationCreatedEvent(BaseEvent):
 
 class AuthorizationRequestApprovedEvent(BaseEvent):
     def __init__(self, id: str, created_at: datetime, amount: str, status: str, approved_amount: str,
-                 partial_approval_allowed: str, merchant: dict[str, str], recurring: str,
-                 tags: Optional[dict[str, str]], relationships: Optional[dict[str, Relationship]]):
+                 partial_approval_allowed: str, merchant: Dict[str, str], recurring: str,
+                 tags: Optional[Dict[str, str]], relationships: Optional[Dict[str, Relationship]]):
         BaseEvent.__init__(self, id, created_at, tags, relationships)
         self.type = 'authorizationRequest.approved'
         self.attributes["amount"] = amount
@@ -105,15 +105,16 @@ class AuthorizationRequestApprovedEvent(BaseEvent):
     @staticmethod
     def from_json_api(_id, _type, attributes, relationships):
         return AuthorizationRequestApprovedEvent(_id, date_utils.to_datetime(attributes["createdAt"]),
-                                                 attributes["amount"], attributes["status"], attributes["approvedAmount"],
-                                                 attributes["partialApprovalAllowed"], attributes["merchant"],
-                                                 attributes["recurring"], attributes.get("tags"), relationships)
+                                                 attributes["amount"], attributes["status"],
+                                                 attributes["approvedAmount"], attributes["partialApprovalAllowed"],
+                                                 attributes["merchant"], attributes["recurring"],
+                                                 attributes.get("tags"), relationships)
 
 
 class AuthorizationRequestDeclinedEvent(BaseEvent):
     def __init__(self, id: str, created_at: datetime, amount: str, status: str, decline_reason: str,
-                 partial_approval_allowed: str, merchant: dict[str, str], recurring: str,
-                 tags: Optional[dict[str, str]], relationships: Optional[dict[str, Relationship]]):
+                 partial_approval_allowed: str, merchant: Dict[str, str], recurring: str,
+                 tags: Optional[Dict[str, str]], relationships: Optional[Dict[str, Relationship]]):
         BaseEvent.__init__(self, id, created_at, tags, relationships)
         self.type = 'authorizationRequest.declined'
         self.attributes["amount"] = amount
@@ -127,15 +128,16 @@ class AuthorizationRequestDeclinedEvent(BaseEvent):
     @staticmethod
     def from_json_api(_id, _type, attributes, relationships):
         return AuthorizationRequestDeclinedEvent(_id, date_utils.to_datetime(attributes["createdAt"]),
-                                                 attributes["amount"], attributes["status"], attributes["declineReason"],
-                                                 attributes["partialApprovalAllowed"], attributes["merchant"],
-                                                 attributes["recurring"], attributes.get("tags"), relationships)
+                                                 attributes["amount"], attributes["status"],
+                                                 attributes["declineReason"], attributes["partialApprovalAllowed"],
+                                                 attributes["merchant"], attributes["recurring"],
+                                                 attributes.get("tags"), relationships)
 
 
 class AuthorizationRequestPendingEvent(BaseEvent):
     def __init__(self, id: str, created_at: datetime, amount: str, status: str, partial_approval_allowed: str,
-                 merchant: dict[str, str], recurring: str, tags: Optional[dict[str, str]],
-                 relationships: Optional[dict[str, Relationship]]):
+                 merchant: Dict[str, str], recurring: str, tags: Optional[Dict[str, str]],
+                 relationships: Optional[Dict[str, Relationship]]):
         BaseEvent.__init__(self, id, created_at, tags, relationships)
         self.type = 'authorizationRequest.pending'
         self.attributes["amount"] = amount
@@ -149,13 +151,14 @@ class AuthorizationRequestPendingEvent(BaseEvent):
     @staticmethod
     def from_json_api(_id, _type, attributes, relationships):
         return AuthorizationRequestPendingEvent(_id, date_utils.to_datetime(attributes["createdAt"]),
-                                                 attributes["amount"], attributes["status"], attributes["approvedAmount"],
-                                                 attributes["partialApprovalAllowed"], attributes["merchant"],
-                                                 attributes["recurring"], attributes.get("tags"), relationships)
+                                                attributes["amount"], attributes["status"],
+                                                attributes["approvedAmount"], attributes["partialApprovalAllowed"],
+                                                attributes["merchant"], attributes["recurring"], attributes.get("tags"),
+                                                relationships)
 
 class CardActivatedEvent(BaseEvent):
-    def __init__(self, id: str, created_at: datetime, tags: Optional[dict[str, str]],
-                 relationships: Optional[dict[str, Relationship]]):
+    def __init__(self, id: str, created_at: datetime, tags: Optional[Dict[str, str]],
+                 relationships: Optional[Dict[str, Relationship]]):
         BaseEvent.__init__(self, id, created_at, tags, relationships)
         self.type = 'card.activated'
 
@@ -167,7 +170,7 @@ class CardActivatedEvent(BaseEvent):
 
 class CardStatusChangedEvent(BaseEvent):
     def __init__(self, id: str, created_at: datetime, new_status: str, previous_status: str,
-                 tags: Optional[dict[str, str]], relationships: Optional[dict[str, Relationship]]):
+                 tags: Optional[Dict[str, str]], relationships: Optional[Dict[str, Relationship]]):
         BaseEvent.__init__(self, id, created_at, tags, relationships)
         self.type = 'card.statusChanged'
         self.attributes["newStatus"] = new_status
@@ -180,8 +183,8 @@ class CardStatusChangedEvent(BaseEvent):
 
 
 class CheckDepositCreatedEvent(BaseEvent):
-    def __init__(self, id: str, created_at: datetime, status: str, tags: Optional[dict[str, str]],
-                 relationships: Optional[dict[str, Relationship]]):
+    def __init__(self, id: str, created_at: datetime, status: str, tags: Optional[Dict[str, str]],
+                 relationships: Optional[Dict[str, Relationship]]):
         BaseEvent.__init__(self, id, created_at, tags, relationships)
         self.type = 'checkDeposit.created'
         self.attributes["status"] = status
@@ -192,8 +195,8 @@ class CheckDepositCreatedEvent(BaseEvent):
                                       attributes["status"], attributes.get("tags"), relationships)
 
 class CheckDepositClearingEvent(BaseEvent):
-    def __init__(self, id: str, created_at: datetime, previous_status: str, tags: Optional[dict[str, str]],
-                 relationships: Optional[dict[str, Relationship]]):
+    def __init__(self, id: str, created_at: datetime, previous_status: str, tags: Optional[Dict[str, str]],
+                 relationships: Optional[Dict[str, Relationship]]):
         BaseEvent.__init__(self, id, created_at, tags, relationships)
         self.type = 'checkDeposit.clearing'
         self.attributes["previousStatus"] = previous_status
@@ -205,8 +208,8 @@ class CheckDepositClearingEvent(BaseEvent):
 
 
 class CheckDepositSentEvent(BaseEvent):
-    def __init__(self, id: str, created_at: datetime, previous_status: str, tags: Optional[dict[str, str]],
-                 relationships: Optional[dict[str, Relationship]]):
+    def __init__(self, id: str, created_at: datetime, previous_status: str, tags: Optional[Dict[str, str]],
+                 relationships: Optional[Dict[str, Relationship]]):
         BaseEvent.__init__(self, id, created_at, tags, relationships)
         self.type = 'checkDeposit.sent'
         self.attributes["previousStatus"] = previous_status
@@ -218,8 +221,8 @@ class CheckDepositSentEvent(BaseEvent):
 
 
 class CheckDepositReturnedEvent(BaseEvent):
-    def __init__(self, id: str, created_at: datetime, previous_status: str, tags: Optional[dict[str, str]],
-                 relationships: Optional[dict[str, Relationship]]):
+    def __init__(self, id: str, created_at: datetime, previous_status: str, tags: Optional[Dict[str, str]],
+                 relationships: Optional[Dict[str, Relationship]]):
         BaseEvent.__init__(self, id, created_at, tags, relationships)
         self.type = 'checkDeposit.returned'
         self.attributes["previousStatus"] = previous_status
@@ -231,8 +234,8 @@ class CheckDepositReturnedEvent(BaseEvent):
 
 
 class CustomerCreatedEvent(BaseEvent):
-    def __init__(self, id: str, created_at: datetime, tags: Optional[dict[str, str]],
-                 relationships: Optional[dict[str, Relationship]]):
+    def __init__(self, id: str, created_at: datetime, tags: Optional[Dict[str, str]],
+                 relationships: Optional[Dict[str, Relationship]]):
         BaseEvent.__init__(self, id, created_at, tags, relationships)
         self.type = 'customer.created'
 
@@ -242,8 +245,8 @@ class CustomerCreatedEvent(BaseEvent):
                                     attributes.get("tags"), relationships)
 
 class DocumentApprovedEvent(BaseEvent):
-    def __init__(self, id: str, created_at: datetime, tags: Optional[dict[str, str]],
-                 relationships: Optional[dict[str, Relationship]]):
+    def __init__(self, id: str, created_at: datetime, tags: Optional[Dict[str, str]],
+                 relationships: Optional[Dict[str, Relationship]]):
         BaseEvent.__init__(self, id, created_at, tags, relationships)
         self.type = 'document.approved'
 
@@ -253,12 +256,12 @@ class DocumentApprovedEvent(BaseEvent):
                                     attributes.get("tags"), relationships)
 
 class DocumentRejectedEvent(BaseEvent):
-    def __init__(self, id: str, created_at: datetime, reason: str, reasonCode: str,
-                 tags: Optional[dict[str, str]], relationships: Optional[dict[str, Relationship]]):
+    def __init__(self, id: str, created_at: datetime, reason: str, reason_code: str,
+                 tags: Optional[Dict[str, str]], relationships: Optional[Dict[str, Relationship]]):
         BaseEvent.__init__(self, id, created_at, tags, relationships)
         self.type = 'document.rejected'
         self.attributes["reason"] = reason
-        self.attributes["reasonCode"] = reasonCode
+        self.attributes["reasonCode"] = reason_code
 
     @staticmethod
     def from_json_api(_id, _type, attributes, relationships):
@@ -268,8 +271,8 @@ class DocumentRejectedEvent(BaseEvent):
 
 
 class PaymentClearingEvent(BaseEvent):
-    def __init__(self, id: str, created_at: datetime, previous_status: str, tags: Optional[dict[str, str]],
-                 relationships: Optional[dict[str, Relationship]]):
+    def __init__(self, id: str, created_at: datetime, previous_status: str, tags: Optional[Dict[str, str]],
+                 relationships: Optional[Dict[str, Relationship]]):
         BaseEvent.__init__(self, id, created_at, tags, relationships)
         self.type = 'payment.clearing'
         self.attributes["previousStatus"] = previous_status
@@ -280,8 +283,8 @@ class PaymentClearingEvent(BaseEvent):
                                     attributes.get("tags"), relationships)
 
 class PaymentSentEvent(BaseEvent):
-    def __init__(self, id: str, created_at: datetime, previous_status: str, tags: Optional[dict[str, str]],
-                 relationships: Optional[dict[str, Relationship]]):
+    def __init__(self, id: str, created_at: datetime, previous_status: str, tags: Optional[Dict[str, str]],
+                 relationships: Optional[Dict[str, Relationship]]):
         BaseEvent.__init__(self, id, created_at, tags, relationships)
         self.type = 'payment.sent'
         self.attributes["previousStatus"] = previous_status
@@ -292,8 +295,8 @@ class PaymentSentEvent(BaseEvent):
                                     attributes.get("tags"), relationships)
 
 class PaymentReturnedEvent(BaseEvent):
-    def __init__(self, id: str, created_at: datetime, previous_status: str, tags: Optional[dict[str, str]],
-                 relationships: Optional[dict[str, Relationship]]):
+    def __init__(self, id: str, created_at: datetime, previous_status: str, tags: Optional[Dict[str, str]],
+                 relationships: Optional[Dict[str, Relationship]]):
         BaseEvent.__init__(self, id, created_at, tags, relationships)
         self.type = 'payment.returned'
         self.attributes["previousStatus"] = previous_status
@@ -304,8 +307,8 @@ class PaymentReturnedEvent(BaseEvent):
                                     attributes.get("tags"), relationships)
 
 class StatementsCreatedEvent(BaseEvent):
-    def __init__(self, id: str, created_at: datetime, period: str, tags: Optional[dict[str, str]],
-                 relationships: Optional[dict[str, Relationship]]):
+    def __init__(self, id: str, created_at: datetime, period: str, tags: Optional[Dict[str, str]],
+                 relationships: Optional[Dict[str, Relationship]]):
         BaseEvent.__init__(self, id, created_at, tags, relationships)
         self.type = 'statements.created'
         self.attributes["period"] = period
@@ -317,7 +320,7 @@ class StatementsCreatedEvent(BaseEvent):
 
 class TransactionCreatedEvent(BaseEvent):
     def __init__(self, id: str, created_at: datetime, summary: str, direction: str, amount: str,
-                 tags: Optional[dict[str, str]], relationships: Optional[dict[str, Relationship]]):
+                 tags: Optional[Dict[str, str]], relationships: Optional[Dict[str, Relationship]]):
         BaseEvent.__init__(self, id, created_at, tags, relationships)
         self.type = 'transaction.created'
         self.attributes["summary"] = summary
@@ -327,13 +330,14 @@ class TransactionCreatedEvent(BaseEvent):
     @staticmethod
     def from_json_api(_id, _type, attributes, relationships):
         return TransactionCreatedEvent(_id, date_utils.to_datetime(attributes["createdAt"]), attributes["summary"],
-                                     attributes["direction"], attributes["amount"], attributes.get("tags"), relationships)
+                                       attributes["direction"], attributes["amount"], attributes.get("tags"),
+                                       relationships)
 
 EventDTO = Union[AccountClosedEvent, AccountFrozenEvent, ApplicationDeniedEvent, ApplicationAwaitingDocumentsEvent,
-                     ApplicationPendingReviewEvent, CardActivatedEvent, CardStatusChangedEvent, AuthorizationCreatedEvent,
-                     AuthorizationRequestDeclinedEvent, AuthorizationRequestPendingEvent,
-                     AuthorizationRequestApprovedEvent, DocumentApprovedEvent, DocumentRejectedEvent,
-                     CheckDepositCreatedEvent, CheckDepositClearingEvent, CheckDepositSentEvent,
-                     CheckDepositReturnedEvent, CustomerCreatedEvent, PaymentClearingEvent, PaymentSentEvent,
+                 ApplicationPendingReviewEvent, CardActivatedEvent, CardStatusChangedEvent,
+                 AuthorizationCreatedEvent, AuthorizationRequestDeclinedEvent, AuthorizationRequestPendingEvent,
+                 AuthorizationRequestApprovedEvent, DocumentApprovedEvent, DocumentRejectedEvent,
+                 CheckDepositCreatedEvent, CheckDepositClearingEvent, CheckDepositSentEvent,
+                 CheckDepositReturnedEvent, CustomerCreatedEvent, PaymentClearingEvent, PaymentSentEvent,
                  PaymentReturnedEvent, StatementsCreatedEvent, TransactionCreatedEvent]
 
